All of lore.kernel.org
 help / color / mirror / Atom feed
* [lm-sensors] [PATCH] coretemp: Add Lynnfield CPU
@ 2009-09-15  2:13 Huaxu Wan
  2009-09-16 21:24 ` Rudolf Marek
                   ` (4 more replies)
  0 siblings, 5 replies; 6+ messages in thread
From: Huaxu Wan @ 2009-09-15  2:13 UTC (permalink / raw)
  To: lm-sensors


Add Lynnfield processor support. Lynnfield is a quad-core Nehalem based microprocessor for Desktop market, which is introduced in September 2009.

Signed-off-by: Huaxu Wan <huaxu.wan@linux.intel.com>
Signed-off-by: Kent Liu <kent.liu@linux.intel.com>
---
 drivers/hwmon/coretemp.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/hwmon/coretemp.c b/drivers/hwmon/coretemp.c
index 93c1722..a9a21dc 100644
--- a/drivers/hwmon/coretemp.c
+++ b/drivers/hwmon/coretemp.c
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
        for_each_online_cpu(i) {
                struct cpuinfo_x86 *c = &cpu_data(i);

                /* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
                if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
                    !((c->x86_model = 0xe) || (c->x86_model = 0xf) ||
                        (c->x86_model = 0x16) || (c->x86_model = 0x17) ||
-                       (c->x86_model = 0x1A))) {
+                       (c->x86_model = 0x1A) || (c->x86_model = 0x1E))) {

                        /* supported CPU not found, but report the unknown
                           family 6 CPU */
@@ -413,11 +413,11 @@ static int __init coretemp_init(void)
                struct cpuinfo_x86 *c = &cpu_data(i);

-               /* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
+               /* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A, 0x1E */
                if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
                    !((c->x86_model = 0xe) || (c->x86_model = 0xf) ||
--

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply related	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2009-10-12 20:55 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2009-09-15  2:13 [lm-sensors] [PATCH] coretemp: Add Lynnfield CPU Huaxu Wan
2009-09-16 21:24 ` Rudolf Marek
2009-09-27  9:12 ` Kent Liu
2009-10-10  6:01 ` Kent Liu
2009-10-12 13:40 ` Jean Delvare
2009-10-12 20:55 ` Rudolf Marek

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.